<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.ui" line="14"/>
        <source>Mozc Dictionary Tool</source>
        <translation>Mozc 辞書ツール</translation>
    </message>
    <message>
        <location filename="dictionary_tool.ui" line="31"/>
        <source>toolBar</source>
        <translation>ツールバー</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="find_dialog.ui" line="26"/>
        <source>Mozc Dictionary Find Dialog</source>
        <translation>Mozc 辞書検索</translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="37"/>
        <source>Reading or Word:</source>
        <translation>よみ・単語</translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="54"/>
        <source>Up</source>
        <translation>上に検索</translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="61"/>
        <source>Down</source>
        <translation>下に検索</translation>
    </message>
    <message>
        <location filename="find_dialog.ui" line="68"/>
        <source>Cacnel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="import_dialog.ui" line="26"/>
        <source>Mozc Dictionary Tool</source>
        <translation>Mozc 辞書ツール</translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="75"/>
        <source>File Location</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="82"/>
        <source>Dictionary Name</source>
        <translation>辞書名</translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="89"/>
        <source>Format</source>
        <translation>フォーマット</translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="96"/>
        <source>Encoding</source>
        <translation>エンコード</translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="103"/>
        <source>Select file...</source>
        <translation>ファイルを選択...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="dictionary_tool.cc" line="233"/>
        <source>Importing new words...</source>
        <translation>単語をインポートしています...</translation>
    </message>
</context>
<context>
    <name>RegisterForm</name>
    <message>
        <source>Reading</source>
        <translation type="obsolete">よみ</translation>
    </message>
    <message>
        <source>Word</source>
        <translation type="obsolete">単語</translation>
    </message>
    <message>
        <source>Part of speech</source>
        <translation type="obsolete">品詞</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="obsolete">コメント</translation>
    </message>
    <message>
        <source>Register</source>
        <translation type="obsolete">登録</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">クリア</translation>
    </message>
</context>
<context>
    <name>mozc::gui::DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.cc" line="260"/>
        <source>Mozc</source>
        <translation>Mozc</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="285"/>
        <source>Another process is accessing the user dictionary file.</source>
        <translation>別のアプリケーションが辞書を編集中です。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="349"/>
        <source>Reading</source>
        <translation>よみ</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="349"/>
        <source>Word</source>
        <translation>単語</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="350"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="384"/>
        <source>Rename dictionary...</source>
        <translation>辞書名を変更...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="385"/>
        <source>Delete dictionary</source>
        <translation>選択した辞書を削除</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="389"/>
        <source>Import as new dictionary...</source>
        <translation>新規辞書にインポート...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="391"/>
        <source>Import to current dictionary...</source>
        <translation>選択した辞書にインポート...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="383"/>
        <source>New dictionary...</source>
        <translation>辞書を作成...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="392"/>
        <source>Export current dictionary...</source>
        <translation>選択した辞書をエクスポート...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="399"/>
        <source>Import from %1&apos;s user dictionary...</source>
        <translation>%1 のユーザ辞書をインポート</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="464"/>
        <source>User Dictionary 1</source>
        <translation>ユーザー辞書 1</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="510"/>
        <source>Making dangerously large user dictionary file. If the dictionary file turns out to be larger than 256Mbyte, the dictionary loader skips to handle all the words to prevent the converter from being halted.</source>
        <translation>非常に大きなユーザ辞書を作成しようとしています。辞書サイズが 256MB を超える場合、変換エンジンプログラムのリソース不足による異常動作を回避するためすべての単語がロードされない場合があります。ご了承ください。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="590"/>
        <source>Updating the current view data...</source>
        <translation>テーブルを更新中です...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="628"/>
        <location filename="dictionary_tool.cc" line="704"/>
        <source>You can&apos;t have more than %1 dictionaries.</source>
        <translation>%1 個を超える辞書を作ることはできません。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="633"/>
        <source>Name of the new dictionary</source>
        <translation>辞書名</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="647"/>
        <location filename="dictionary_tool.cc" line="676"/>
        <location filename="dictionary_tool.cc" line="726"/>
        <location filename="dictionary_tool.cc" line="876"/>
        <location filename="dictionary_tool.cc" line="918"/>
        <source>No dictionary is selected.</source>
        <translation>辞書が選択されていません。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="653"/>
        <source>Do you want to delete %1?</source>
        <translation>%1を削除しますか?</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="682"/>
        <source>New name of the dictionary</source>
        <translation>辞書名</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="757"/>
        <source>%1 entries are imported to %2.</source>
        <translation>%1 エントリーを %2 にインポートしました。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="763"/>
        <source>You have imported a file in an invalid or unsupported file format.

Please check the file format. ATOK11 or older format is not supported by Mozc.</source>
        <translation>指定されたファイルは Mozcでサポートされていないフォーマットで保存されています。
	
インポート対象のファイルフォーマットを確認してください。

ATOK・ことえり・MS-IMEのバイナリ形式の辞書はインポートできません。一度ATOK・ことえり・MS-IMEの辞書ツールを使ってテキスト形式として書き出してから、インポートしてください。ATOK11 以前のファイル形式はサポートしていません。
	</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="772"/>
        <source>%1 doesn&apos;t have enough space to import all words in the file. First %2 entries are imported.</source>
        <translation>%1 にはファイル中のすべての単語をインポートするための領域が不足しています。先頭の %2 単語のみインポートします。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="779"/>
        <source>%1 entries are imported to %2.

Some imported words were not recognized by %3. Please check the original import file.</source>
        <translation>%1 エントリーを %2 にインポートしました。

%3 で取り扱えない可能性がある単語が含まれています。元のインポート対象ファイルを確認してください。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="867"/>
        <source>Microsoft IME dictioanry import function doesn&apos;t work on UAC-elevated process.</source>
        <translation>UACで昇格されたアプリケーションからは、Microsoft IME のユーザ辞書を読み込むことができません。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="882"/>
        <source>All user-registered words in %1 are migrated into the current dictionary.</source>
        <translation>%1 のユーザ辞書にある単語を選択された辞書にインポートします</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="786"/>
        <source>Failed to open user dictionary</source>
        <translation>ユーザ辞書のオープンに失敗しました。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1305"/>
        <source>Dictionary name is empty.</source>
        <translation>辞書名が入力されていません。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1310"/>
        <source>Dictionary name is too long.</source>
        <translation>辞書名が長すぎます。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1300"/>
        <source>An invalid character is included in the dictionary name.</source>
        <translation>辞書名に使用できない文字が含まれています。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="300"/>
        <source>Tools</source>
        <translation>管理</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="301"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="923"/>
        <source>Export dictionary</source>
        <translation>辞書をエクスポート</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="302"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="350"/>
        <source>Category</source>
        <translation>品詞</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="733"/>
        <location filename="dictionary_tool.cc" line="955"/>
        <source>You can&apos;t have more than %1 words in one dictionary.</source>
        <translation>%1 語を超える単語を 1 つの辞書の中に持つことはできません。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="924"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation>テキスト ファイル (*.txt);;すべてのファイル(*)</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="802"/>
        <location filename="dictionary_tool.cc" line="932"/>
        <source>Can&apos;t open %1.</source>
        <translation>%1を開けません。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="386"/>
        <source>Find...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="945"/>
        <source>Dictionary export finished.</source>
        <translation>辞書のエクスポートが完了しました。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="993"/>
        <source>Do you want to delete this word?</source>
        <translation>この単語を削除しますか？</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="995"/>
        <source>Do you want to delete the selected words?</source>
        <translation>選択された単語を削除しますか？</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1009"/>
        <source>Deleting the selected words...</source>
        <translation>単語を削除しています...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1060"/>
        <source>New comment</source>
        <translation>新しいコメント</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1092"/>
        <source>An invalid character is included in the reading.</source>
        <translation>よみに使用できない文字が含まれています。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1125"/>
        <source>Add a word</source>
        <translation>単語を追加</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1130"/>
        <source>Delete this word</source>
        <translation>この単語を削除</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1137"/>
        <source>Delete the selected words</source>
        <translation>選択した単語を削除</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1145"/>
        <source>Change category to</source>
        <translation>品詞を変更</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1153"/>
        <source>Edit comment</source>
        <translation>コメントを編集</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1178"/>
        <source>Rename...</source>
        <translation>辞書名を変更...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1179"/>
        <source>Delete</source>
        <translation>この辞書を削除</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1180"/>
        <source>Import to this dictionary...</source>
        <translation>この辞書にインポート...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1181"/>
        <source>Export this dictionary...</source>
        <translation>この辞書をエクスポート...</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1315"/>
        <source>Dictionary already exists.</source>
        <translation>同一名称の辞書がすでに存在します。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1320"/>
        <source>A fatal error occurred.</source>
        <translation>エラーが発生しました。</translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1432"/>
        <source>%1: %2 entries</source>
        <translation>%1: 総数 %2個</translation>
    </message>
</context>
<context>
    <name>mozc::gui::FindDialog</name>
    <message>
        <location filename="find_dialog.cc" line="127"/>
        <source>Cannot find pattern %1</source>
        <translation>%1 は見つかりませんでした。</translation>
    </message>
</context>
<context>
    <name>mozc::gui::ImportDialog</name>
    <message>
        <location filename="import_dialog.cc" line="26"/>
        <location filename="import_dialog.cc" line="55"/>
        <source>Auto detection</source>
        <translation>自動判定</translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="29"/>
        <source>Google</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="34"/>
        <location filename="import_dialog.cc" line="50"/>
        <source>Microsoft IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="37"/>
        <location filename="import_dialog.cc" line="47"/>
        <source>ATOK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="40"/>
        <location filename="import_dialog.cc" line="44"/>
        <source>Kotoeri</source>
        <translation>ことえり</translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="58"/>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="61"/>
        <source>Shift JIS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="64"/>
        <source>UTF-8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="69"/>
        <source>Import</source>
        <translation>インポート</translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="161"/>
        <source>Import dictionary</source>
        <translation>辞書をインポート</translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="163"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation>テキスト ファイル (*.txt);;すべてのファイル(*)</translation>
    </message>
</context>
<context>
    <name>mozc::gui::RegisterForm</name>
    <message>
        <source>Register word</source>
        <translation type="obsolete">新しい単語</translation>
    </message>
    <message>
        <source>Modify word</source>
        <translation type="obsolete">単語を修正</translation>
    </message>
</context>
</TS>
